PyLucene.Field

PyLucene :: Field :: Class Field |
[hide private]
[frames] | no frames]

# Class Field

j_field objects

Instance Methods | [hide private]
Index(...) const variable descriptor |
Store(...) const variable descriptor |
TermVector(...) const variable descriptor |
__init__(...) x.__init__(...) initializes x; see x.__class__.__doc__ for signature |
binaryValue(...) |
getBoost(...) |
getOmitNorms(...) |
isBinary(...) |
isCompressed(...) |
isIndexed(...) |
isStoreOffsetWithTermVector(...) |
isStorePositionWithTermVector(...) |
isStored(...) |
isTermVectorStored(...) |
isTokenized(...) |
name(...) |
readerValue(...) |
setBoost(...) |
setOmitNorms(...) |
stringValue(...) |
Inherited from `Object`: `__eq__`, `__ge__`, `__gt__`, `__hash__`, `__le__`, `__lt__`, `__ne__`, `__new__`, `__repr__`, `__str__`, `equals`, `getClass`, `hashCode`, `notify`, `notifyAll`, `toString`, `wait` Inherited from `object`: `__delattr__`, `__getattribute__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(...) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: Object.__init__